gchecky.controller

Package gchecky :: Module controller |
[hide private]
[frames] | no frames]

# Module controller

source code

Classes | [hide private]
| ProcessingException
| html_order TODO:
| ControllerLevel_1
| ControllerContext
| GcheckyError Base class for exception that could be thrown by gchecky library.
| DataError An exception of this class occures whenever there is error in converting python data to/from xml.
| HandlerError An exception of this class occures whenever an exception is thrown from user defined handler.
| SystemError An exception of this class occures whenever there is a system error, such as network being unavailable or DB down.
| LibraryError An exception of this class occures whenever there is a bug encountered in gchecky library.
| ControllerLevel_2
| Controller

Functions | [hide private]
html_escape(html) A simple helper that escapes '<', '>' and '&' to make sure the text is safe to be output directly into html text flow. | source code

Function Details | [hide private]

### html_escape(html) | source code
A simple helper that escapes '<', '>' and '&' to make sure the text is safe to be output directly into html text flow. @param html A (unicode or not) string to be escaped from html.
    >>> safe_str = 'Is''n it a text "with": some  fancy characters ;-)?!'
    >>> html_escape(safe_str) == safe_str
    True
    >>> html_escape('Omg&, <this> is not &a safe string <to> &htmlize >_<!')
    'Omg&amp;, &lt;this&gt; is not &amp;a safe string &lt;to&gt; &amp;htmlize &gt;_&lt;!'